---
title: <span class="badge builder"></span> LineStyle
---
# <span class="badge builder"></span> LineStyle

## Constructor

```python
LineStyle()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> common.LineStyle
```

### <span class="badge object-method"></span> dash

```python
def dash(dash: list[float]) -> typing.Self
```

### <span class="badge object-method"></span> fill

```python
def fill(fill: typing.Literal["solid", "dash", "dot", "square"]) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [LineStyle](./object-LineStyle.md)
